**Example 1: 删除节点**



Input: 

```
tccli tiems DeleteInstance --cli-unfold-argument  \
    --InstanceId ins-xxxxxxxx
```

Output: 
```
{
    "Response": {
        "RequestId": "0e21c605-3d85-4fc0-bc91-4c61ca250ad5"
    }
}
```

